@@ -6,10 +6,11 @@ from unittest.mock import patch
 import dateutil.relativedelta as rd
 import pandas
 
-from . import CoreCalendarTest
+from . import CoreCalendarTest, GenericCalendarTest
 from ..core import Holiday
 from ..core import (
     MON, TUE, THU, FRI, WED, SAT, SUN,
+    ISO_TUE, ISO_FRI,
     Calendar, LunarMixin, WesternCalendar,
     CalverterMixin, IslamicMixin, JalaliMixin,
     daterange,
@@ -107,6 +108,34 @@ class CalendarTest(CoreCalendarTest):
             date(2015, 4, 14)
         )
 
+    def test_get_iso_week_date(self):
+        # Find the MON of the week 1 in 2021
+        self.assertEqual(
+            Calendar.get_iso_week_date(2021, 1),
+            date(2021, 1, 4)
+        )
+        # Find the FRI of the week 1 in 2021
+        self.assertEqual(
+            Calendar.get_iso_week_date(2021, 1, ISO_FRI),
+            date(2021, 1, 8)
+        )
+
+        # Find the TUE of the week 44 in 2021
+        self.assertEqual(
+            Calendar.get_iso_week_date(2021, 44, ISO_TUE),
+            date(2021, 11, 2)
+        )
+
+    # Remove this test when dropping support for Python 3.7
+    @patch('calendra.core.sys')
+    def test_get_iso_week_date_patched(self, mock_sys):
+        # The Python 3.6-3.7 backport should always work
+        mock_sys.version_info = (3, 6, 0)
+        self.assertEqual(
+            Calendar.get_iso_week_date(2021, 44, ISO_TUE),
+            date(2021, 11, 2)
+        )
+
 
 class LunarCalendarTest(TestCase):
 
@@ -390,6 +419,14 @@ class NoWeekendCalendarTest(CoreCalendarTest):
             self.cal.is_working_day(day)
 
 
+class GenericCalendarTestTest(GenericCalendarTest):
+    cal_class = NoWeekendCalendar
+
+    def test_weekend_days(self):
+        with self.assertRaises(AssertionError):
+            super().test_weekend_days()
+
+
 class WeekendOnWednesdayCalendar(Calendar):
     """
     This calendar class weekend days is on Wednesday and we don't overwrite
@@ -415,7 +452,7 @@ class OverwriteGetWeekendDaysCalendar(Calendar):
     Should work.
     """
     def get_weekend_days(self):
-        return (WED,)
+        return WED,
 
 
 class OverwriteGetWeekendDaysCalendarTest(CoreCalendarTest):
@@ -521,6 +558,61 @@ class WorkingDaysDeltatest(TestCase):
         delta = cal.get_working_days_delta(day1, day2, include_start=True)
         self.assertEqual(delta, 1)
 
+    def test_use_extra_working_days(self):
+        cal = MockChristianCalendar()
+        day1 = date(2018, 12, 21)
+        day2 = date(2018, 12, 26)
+        delta = cal.get_working_days_delta(
+            day1, day2,
+            extra_working_days=[date(2018, 12, 25)]
+        )
+        # there are 3 days, because of the week-end
+        # and Christmas Day is a working day
+        self.assertEqual(delta, 3)
+
+        # No difference if you swap the two dates
+        delta = cal.get_working_days_delta(
+            day2, day1,
+            extra_working_days=[date(2018, 12, 25)])
+        self.assertEqual(delta, 3)
+
+    def test_use_extra_holidays(self):
+        cal = MockChristianCalendar()
+        day1 = date(2018, 12, 21)
+        day2 = date(2018, 12, 26)
+        delta = cal.get_working_days_delta(
+            day1, day2,
+            extra_holidays=[date(2018, 12, 24)]
+        )
+        # Only 1 day, because of the week-end + XMas + XMas Eve
+        self.assertEqual(delta, 1)
+
+        # No difference if you swap the two dates
+        delta = cal.get_working_days_delta(
+            day2, day1,
+            extra_holidays=[date(2018, 12, 24)])
+        self.assertEqual(delta, 1)
+
+    def test_use_both_extra(self):
+        cal = MockChristianCalendar()
+        day1 = date(2018, 12, 21)
+        day2 = date(2018, 12, 26)
+        delta = cal.get_working_days_delta(
+            day1, day2,
+            extra_working_days=[date(2018, 12, 25)],
+            extra_holidays=[date(2018, 12, 24)]
+        )
+        # Only 1 day, because of the week-end + XMas Eve
+        # And Christmas is a working day
+        self.assertEqual(delta, 2)
+
+        # No difference if you swap the two dates
+        delta = cal.get_working_days_delta(
+            day2, day1,
+            extra_working_days=[date(2018, 12, 25)],
+            extra_holidays=[date(2018, 12, 24)])
+        self.assertEqual(delta, 2)
+
 
 class NoDocstring(Calendar):
     pass
